import pandas as pd
import numpy as np
import sys
from ipydatagrid import DataGrid

class DynamicDataEntry:
    """
    DynamicDataEntry

    Uses the ipydatagrid widget to allow interactive data frame entry with data stored in a csv file.

    INPUTS:
    fname - name of CSV file associated with the data (doesn't need to exist yet)
    columns - list of strings specifying the names of columns (only used if CSV file doesn't exist)
    num_rows - number of rows in data file
    """
    def __init__(self,fname,columns,num_rows):
        self.max_height = 200
        self.in_colab = "google.colab" in sys.modules
        if self.in_colab:
            from google.colab import output
            output.enable_custom_widget_manager()
        self.fname = fname
        try:
            df = pd.read_csv(self.fname)
        except FileNotFoundError:
            d = {}
            for col in columns:
                d[col] = np.zeros(num_rows)
            df = pd.DataFrame(data=d)
        height = min(20*num_rows + 30, self.max_height)
        self.dg = DataGrid(df, editable=True, layout={'height': f"{height}px"}, auto_fit_columns=True,selection_mode='row')

    def edit_sheet(self):
        return self.dg
  
    def save(self):
        self.dg.data.to_csv(self.fname,index=False)
  
    def get_dataframe(self):
        return self.dg.data.copy(deep=True)


"""Load git environment settings

Looks for .env or dotenv file. If in Google Colab, tries to mount Google Drive
and look for the .env/dotenv file in /content/drive/MyDrive.
"""
# Approach inspired by the work of GitHub user ffreemt
# found at https://github.com/ffreemt/colab-misc-utils
import sys
from pydantic_settings import BaseSettings
from pathlib import Path

class git_settings(BaseSettings):
    user_name: str = ""
    user_email: str = ""
    gh_token: str = ""

    class Config:
        env_file = None # default setting
        if "google.colab" in sys.modules:
            basedir = Path("/content/drive/MyDrive")
            # if Google Drive is not mounted, do that now
            if not basedir.is_dir():
                from google.colab import drive
                drive.mount('/content/drive')
        else:
            basedir = Path.home()
        if basedir.joinpath(".env").is_file():
            env_file = basedir.joinpath(".env")
        elif basedir.joinpath("dotenv").is_file():
            env_file = basedir.joinpath("dotenv")
        elif basedir.joinpath("dotenv.txt").is_file():
            env_file = basedir.joinpath("dotenv.txt")



